@@ -6,7 +6,7 @@ import site
 NON_USERDEFINED_PATHES = [
     sysconfig.get_python_lib(standard_lib=True, prefix=os.path.realpath(sys.prefix)),
     sysconfig.get_python_lib(standard_lib=True),
-] ++ site.getsitepackages()
+] + site.getsitepackages()
 
 def dumps(m):
     return m.__name__
